<?php
/**
 * Core Theme Functions
 * 
 * @package Purosa
 * @version 1.0.0
 */

 
/**
 * Checks if WooCommerce is activated
 * @return boolean
 */
function purosa_is_woocommerce_activated() {
	return class_exists( 'WooCommerce' ) ? true : false;
}


/**
	* Check if page built with Elementor
	*
	* @since  1.0.0
	*/
function purosa_is_elementor_page() {
	$elementor_page = get_post_meta( get_the_ID(), '_elementor_edit_mode', true );

	if ( is_search() || is_archive() ) {
		return false;
	}

	if ( (bool)$elementor_page ) {
		return true;
	} else {
		return false;
	}	
}


if ( ! function_exists( 'wp_body_open' ) ) {

	/**
	 * Shim for wp_body_open, ensuring backwards compatibility with versions < 5.2
	 *
	 * @since 1.0.0
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
}


/**
 * Allow shorcodes in text widgets
 */
add_filter( 'widget_text', 'do_shortcode' );


/**
 * Categories dropdown
 */
function purosa_categories_dropdown() {

	$categories = get_categories( array(
		'orderby' => 'name',
		'parent'  => 0
	) );

	$categories_dropdown = array( '0' => esc_html__( 'All categories', 'purosa' ) );
	if ( ! is_wp_error( $categories ) ) {
		foreach ( $categories as $key => $category ) {
			$categories_dropdown[$category->term_id] = $category->name;
		}
	}

	return $categories_dropdown;
}


/**
 * Post date meta
 */
if ( ! function_exists( 'purosa_meta_date' ) ) {
	function purosa_meta_date() {

		if ( get_theme_mod( 'purosa_display_publish_date_as_time_ago', true ) ) {
			$posted_on = get_the_time();
			$posted_on = sprintf( _x( '%s ago', '%s = human-readable time difference', 'purosa' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) );
			$output = sprintf('<span class="entry__meta-item entry__meta-date">%s</span>', $posted_on );
		} else {
			$posted_on = get_the_date();
			$output = sprintf( '<span class="entry__meta-item entry__meta-date">%s</span>', $posted_on );
		}

		echo wp_kses_post( $output );
	}
}



/**
 * Post comments meta
 */
if ( ! function_exists( 'purosa_meta_comments' ) ) {
	function purosa_meta_comments() {
		$comments_num = get_comments_number();
		$output = '';

		if ( comments_open() ) {
			if( $comments_num == 0 ) {
				$comments = esc_html__( '0 Comments', 'purosa' );
			} elseif ( $comments_num > 1 ) {
				$comments = $comments_num . esc_html__(' Comments', 'purosa');
			} else {
				$comments = esc_html__('1 Comment', 'purosa');
			}
			$comments = sprintf('<span class="entry__meta-item"><a href="%1$s" class="entry__meta-comments">%2$s</a></span>', get_comments_link(), $comments );
		} else {
			$comments = esc_html__('Comments are closed', 'purosa');
		}

		$output .= $comments;
		echo wp_kses_post( $output );
	}
}


/**
 * Post category meta
 */
if ( ! function_exists( 'purosa_meta_category' ) ) {
	function purosa_meta_category() {
		$categories = get_the_category();
		$separator = ' ';
		$categories_output = '';
		$output = '';

		if ( !empty($categories) ):    
			foreach( $categories as $index => $category ):
				if ($index > 0) : $categories_output .= $separator; endif;
				$categories_output .= '<span class="entry__meta-item entry__meta-item-category"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" class="entry__meta-category">' . esc_html( $category->name ) . '</a></span>';
			endforeach;
		endif;

		if ( 'post' == get_post_type() ) :
			$output .= $categories_output;
		endif;

		echo wp_kses_post( $output );

	}
}


/**
 * Post author meta
 */
if ( ! function_exists( 'purosa_meta_author' ) ) {
	function purosa_meta_author() {
		$author_nicename = get_the_author_meta( 'user_nicename' );
		if ( ! empty( $author_nicename ) ) : ?>
			<span class="entry__meta-item">
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" class="entry__meta-author" title="<?php echo esc_attr( get_the_author() ); ?>"><?php the_author(); ?></a>
			</span>
		<?php endif;
	}
}



if ( ! function_exists( 'purosa_author_box' ) ) {
	/**
	* Author Box
	*/
	function purosa_author_box() {

		$output = '';

		ob_start();

		$socials = [
			'facebook'  => get_the_author_meta( 'facebook' ),
			'twitter'   => get_the_author_meta( 'twitter' ),
			'linkedin'  => get_the_author_meta( 'linkedin' ),
			'instagram' => get_the_author_meta( 'instagram' ),
			'youtube'   => get_the_author_meta( 'youtube' ),
			'vimeo'     => get_the_author_meta( 'vimeo' ),
			'pinterest' => get_the_author_meta( 'pinterest' ),			
			'github' 		=> get_the_author_meta( 'github' ),		
			'snapchat'  => get_the_author_meta( 'snapchat' ),
		];

		$website = rtrim( get_the_author_meta( 'url' ), '/' );

		if ( get_the_author_meta( 'description' ) ) : ?>
			<div class="entry-author entry-author--box clearfix">
				<figure itemscope itemprop="image" class="entry-author__img-holder">
					<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">
						<?php echo get_avatar( get_the_author_meta( 'ID' ), 64, null, null, array( 'class' => array( 'entry-author__img' ) ) ); ?>
					</a>                
				</figure>
				<div class="entry-author__info">
					<h6 class="entry-author__name" itemprop="url" rel="author">
						<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>" itemprop="name">
							<span itemprop="author" itemscope itemtype="https://schema.org/Person" class="entry-author__name">
								<?php the_author_meta( 'display_name' ); ?>
							</span>
						</a>
					</h6>
					<?php if ( ! empty( $website ) ) : ?>
						<a href="<?php echo esc_url( $website ); ?>" class="entry-author__website" rel="noopener nofollow" target="_blank">
							<span class="entry-author__website-text"><?php echo esc_url( $website ); ?></span>
						</a>
					<?php endif; ?>
					<div class="entry-author__description"><?php the_author_meta( 'description' ); ?></div>

					
					<?php if (
						get_the_author_meta( 'facebook' ) ||
						get_the_author_meta( 'twitter' ) ||
						get_the_author_meta( 'linkedin' ) ||
						get_the_author_meta( 'instagram' ) ||
						get_the_author_meta( 'youtube' ) ||
						get_the_author_meta( 'vimeo' ) ||
						get_the_author_meta( 'pinterest' ) ||
						get_the_author_meta( 'github' ) ||
						get_the_author_meta( 'snapchat' )
					) : ?>
					
						<!-- Socials -->
						<div class="entry-author__socials socials socials--medium socials--colored-base">
							<?php foreach ( $socials as $key => $value ) {
								if ( $value ) : ?>
									<a href="<?php echo esc_url( the_author_meta( $key ) ); ?>" class="social social-<?php echo esc_attr( $key ); ?>" title="<?php echo esc_attr( $key ); ?>" rel="noopener nofollow" target="_blank">
										<i class="ui-<?php echo esc_attr( $key ); ?>"></i>
									</a>
								<?php endif;
							} ?>
						</div>
					<?php endif; ?>

				</div>
			</div>
		<?php endif;

		$output = ob_get_clean();

		echo wp_kses_post( $output );
	}
}



/**
* Gutenberg Check
**/
function purosa_is_gutenberg() {
	return function_exists( 'register_block_type' ); 
}

if ( ! function_exists( 'purosa_multi_page_pagination' ) ) {
	/**
	* Multi-page pagination
	*
	* @since 1.0.0
	*/
	function purosa_multi_page_pagination() {
		$defaults = array(
			'before'           => '<nav class="post-pagination">' . '<span>' . esc_html( 'Pages:', 'purosa' ) . '</span>',
			'after'            => '</nav>',
			'link_before'      => '<span class="post-pagination__number">',
			'link_after'       => '</span>',
			'next_or_number'   => 'number',
			'separator'        => ' ',
			'nextpagelink'     => esc_html( 'Next page', 'purosa' ),
			'previouspagelink' => esc_html( 'Previous page', 'purosa' ),
			'pagelink'         => '%',
			'echo'             => 1
		);

		wp_link_pages( $defaults );
	}
}


/**
* Comments Pagination
**/
if ( ! function_exists( 'purosa_comments_pagination' ) ) {
	function purosa_comments_pagination() {

		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :

			?>

			<nav class="comment-navigation clearfix" role="navigation">
				<h6 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'purosa' ); ?></h6>
				<div class="nav-previous"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'purosa' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'purosa' ) ); ?></div>
			</nav><!-- #comment-nav-above -->

			<?php

		endif;
	}
}



/**
 * Display navigation to next/previous set of posts when applicable.
 */

if ( ! function_exists( 'purosa_post_pagination' ) ) :
	function purosa_post_pagination() {
		// Don't print empty markup if there's only one page.
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		} ?>

		<!-- Pagination Numbers -->
		<nav class="pagination clearfix">
			<?php $args = array(
				'prev_next'          => true,
				'prev_text'          => wp_kses( '<i class="ui-arrow-left"></i>', array( 'i' => array( 'class' => array() ) ) ),
				'next_text'          => wp_kses( '<i class="ui-arrow-right"></i>', array( 'i' => array( 'class' => array() ) ) ),
			); ?>
			<?php echo paginate_links( $args ); ?>
		</nav>

		<?php
	}
endif;



/**
 * Display navigation to next/previous post when applicable.
 */
if ( ! function_exists( 'purosa_post_nav' ) ) :
	function purosa_post_nav() {
		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );
		$get_next_post = get_next_post();
		$get_previous_post = get_previous_post();
		if ( ! empty( $get_previous_post ) ) {
			$previous_post_thumbnail = get_the_post_thumbnail_url( $get_previous_post->ID, 'purosa_thumbnail' );
		}
		if ( ! empty( $get_next_post ) ) {
			$next_post_thumbnail = get_the_post_thumbnail_url( $get_next_post->ID, 'purosa_thumbnail' );
		}

		if ( ! $next && ! $previous ) {
			return;
		}
		?>
		
		<nav class="entry-navigation">
			<h5 class="screen-reader-text"><?php esc_html__( 'Post navigation', 'purosa' ); ?></h5>
			<div class="entry-navigation__row clearfix">

				<?php if ( ! empty( $get_next_post ) ) : ?>
					<div class="entry-navigation__col entry-navigation--left">
						<div class="entry-navigation__item">
							<?php if ( ! empty( $next_post_thumbnail ) ) : ?>
								<div class="entry-navigation__item-img" style="background-image: url(<?php echo esc_url( $next_post_thumbnail ); ?>)">
									<?php next_post_link( '%link', '' ); ?>
								</div>
							<?php endif; ?>
							<div class="entry-navigation__body">
								<?php
									printf( '<i class="ui-arrow-left"></i><span class="entry-navigation__label">%s</span>', esc_html__('Previous Post', 'purosa') );
									next_post_link( '<h6 class="entry-navigation__title">%link</h6>', _x( '%title', 'Next post link', 'purosa' ) );
								?>
							</div>
						</div>
					</div>
				<?php endif; ?>
				<?php if ( ! empty( $get_previous_post ) ) : ?>
					<div class="entry-navigation__col entry-navigation--right">
						<div class="entry-navigation__item">
							<div class="entry-navigation__body">
								<?php
									printf( '<span class="entry-navigation__label">%s</span><i class="ui-arrow-right"></i>', esc_html__('Next Post', 'purosa') );
									previous_post_link( '<h6 class="entry-navigation__title">%link</h6>', _x( '%title', 'Previous post link', 'purosa' ) );  
								?>
							</div>
							<?php if ( ! empty( $previous_post_thumbnail ) ) : ?>
								<div class="entry-navigation__item-img" style="background-image: url(<?php echo esc_url( $previous_post_thumbnail ); ?>)">
									<?php previous_post_link( '%link', '' ); ?>
								</div>
							<?php endif; ?>
						</div>
					</div>
				<?php endif; ?>
			</div> <!-- .entry-navigation__row -->
		</nav>
		<?php
	}
endif;


/**
 * Sidebars
 */
function purosa_sidebar() {
	if ( is_active_sidebar( 'purosa-sidebar' ) ) {
		?>
			<aside class="col-lg-4 sidebar">
				<?php get_sidebar(); ?>
			</aside>
		<?php
	}
}



/**
 * Related Posts
 */
function purosa_related_posts() {
	$args = array(
		'post_type'=>'post',
		'post_status' => 'publish',
		'posts_per_page' => 3,
		'post__not_in' => array( get_the_ID() ),
		'ignore_sticky_posts' => true,
		'meta_query' => array( 
			array(
				'key' => '_thumbnail_id'
			) 
		),
	);

	$recent_posts_query = new WP_Query( $args ); ?>

	<?php if ( $recent_posts_query->have_posts() ) : ?>

		<div class="related-posts">
			<h5 class="related-posts__title title-underline"><?php echo esc_html__( 'You Might Like', 'purosa'); ?></h5>
			<div class="row">

				<?php while( $recent_posts_query->have_posts() ) : $recent_posts_query->the_post(); ?>

					<div class="col-md-4">
						<article <?php post_class( 'entry' ); ?>>

							<?php if ( has_post_thumbnail() ) : ?>
								<!-- Post thumb -->
								<div class="entry__img-holder">
									<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
										<?php the_post_thumbnail( 'medium', array( 'class' => 'entry__img' ) ); ?>
									</a>
								</div>
							<?php endif; ?>

							<div class="entry__body">
								<div class="entry__header">
									<?php the_title( sprintf( '<h4 class="entry__title entry__title--small"><a href="%s">', esc_url( get_permalink() ) ), '</a></h4>' ); ?>
								</div>
							</div> <!-- .entry__body -->

						</article><!-- #post-## -->
					</div>
					
				<?php endwhile; ?>

				<?php wp_reset_postdata(); ?>

			</div> <!-- .row -->
		</div> <!-- .related-posts -->
	<?php endif;
}


/**
 * Custom excerpt length
 */
function purosa_custom_excerpt_length( $length ) {

	// Check if Elementor installed and activated
	if ( did_action( 'elementor/loaded' ) ) {
		$elementor_editor = \Elementor\Plugin::$instance->editor->is_edit_mode();
	}	

	if ( is_admin() && ! $elementor_editor ) {
		return;
	}

	$excerpt_length = get_theme_mod( 'purosa_post_excerpt_length', 30 );
	return $excerpt_length;
}
add_filter( 'excerpt_length', 'purosa_custom_excerpt_length' );




/**
 * Tags Cloud Widget font size
 */

function purosa_tag_cloud_size( $args ) {

	$args['smallest'] = 10;
	$args['largest'] = 10;
	return $args;
}

add_filter('widget_tag_cloud_args', 'purosa_tag_cloud_size');



/**
* Get layout columns
*
* @since 1.2.0
*/
if ( ! function_exists( 'purosa_get_columns' ) ) {
	function purosa_get_columns() {
		$columns = '';
		$home_page_columns = get_theme_mod( 'purosa_home_page_columns', 'col-lg-6' );
		$archive_columns = get_theme_mod( 'purosa_archives_columns', 'col-lg-4' );

		if ( is_home() ) {
			$columns = $home_page_columns;
		}

		if ( is_archive() || is_search() ) {
			$columns = $archive_columns;
		}

		return $columns;
	}
}


if ( ! function_exists( 'purosa_layout_type' ) ) {
	/**
	 * Check layout type
	 * @return string $type Layout type
	 */
	function purosa_layout_type( $type, $default = 'fullwidth' ) {
		$layout = '';

		if ( 'left-sidebar' == get_theme_mod( 'purosa_' . $type .  '_layout_type', $default ) ) {
			$layout = 'left-sidebar';
		}

		if ( 'right-sidebar' == get_theme_mod( 'purosa_' . $type .  '_layout_type', $default ) ) {
			$layout = 'right-sidebar';
		}

		if ( 'fullwidth' == get_theme_mod( 'purosa_' . $type .  '_layout_type', $default ) ) {
			$layout = 'fullwidth';
		}	

		return $layout;
	}
}



/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function purosa_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Page Layout Class
	if ( is_page() ) {
		$classes[] = purosa_layout_type( 'page' );
	}

	// Home Page Layout Class
	if ( is_home() ) {
		$classes[] = purosa_layout_type( 'home', 'right-sidebar' );	
	}

	// Blog Layout Class
	if ( is_single() ) {
		if ( purosa_is_woocommerce_activated() && is_product() ) {
			$classes[] = '';
		} else {
			$classes[] = purosa_layout_type( 'blog' );
		}		
	}
	
	// Shop Layout Class
	if ( purosa_is_woocommerce_activated() ) {
		if ( is_woocommerce() || is_shop() ) {
			$classes[] = purosa_layout_type( 'shop' );
		}
	}
    
	// Archives Layout Class
	if ( is_archive() ) {
		if ( purosa_is_woocommerce_activated() && is_shop() ) {
			$classes[] = '';
		} else {
			$classes[] = purosa_layout_type( 'archives' );
		}		
	}

	$classes[] = '';

	return $classes;
}
add_filter( 'body_class', 'purosa_body_classes' );


/**
 * Adds custom admin classes.
 *
 * @param string $classes Classes for the body element.
 * @return string
 */
function purosa_admin_body_classes( $classes ) {

	$screen = get_current_screen();

	// Add blog layout class
	if( $screen->id === "post" ) {
		$classes = purosa_layout_type( 'blog' );
	}

	// Add page layout class
	if( $screen->id === "page" ) {
		$classes = purosa_layout_type( 'page' );
	}
	
	return $classes;
}
add_filter( 'admin_body_class', 'purosa_admin_body_classes' );


/**
 * Sanitize HTML input
 */
function purosa_sanitize_html( $input ) {
	return wp_kses( $input, array(
		'a' => array(
			'href' => array(),
			'target' => array(),
		),
		'i' => array(),
		'span' => array(),
		'em' => array(),
		'strong' => array(),
	) );
}